
#ifndef _C1_kl27_
#define _C1_kl27_

#ifdef __cplusplus
extern "C" {
#endif

RTOSHF (EIF_REFERENCE,656)
static EIF_REFERENCE F45_656_body(EIF_REFERENCE);
extern EIF_REFERENCE F45_656(EIF_REFERENCE);
extern void EIF_Minit27(void);

#ifdef __cplusplus
}
#endif

#endif
